@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemBasicPlugin.cpp 4180 2007-04-01 23:37:46Z hadess $
+ * $Id: totemBasicPlugin.cpp 4463 2007-07-27 16:07:42Z fcrozat $
  */
 
 #include <mozilla-config.h>
@@ -50,10 +50,16 @@ static const char kPluginDescription[] = "Totem Web Browser Plugin " VERSION;
 
 static const totemPluginMimeEntry kMimeTypes[] = {
 	{ "application/ogg", "ogg", NULL },
+	{ "audio/ogg", "ogg", NULL },
+	{ "audio/x-ogg", "ogg", NULL },
+	{ "video/ogg", "ogg", NULL },
+	{ "video/x-ogg", "ogg", NULL },
 	{ "video/mpeg", "mpg, mpeg, mpe", NULL },
 	{ "audio/wav", "wav", NULL },
 	{ "audio/x-wav", "wav", NULL },
 	{ "audio/mpeg", "mp3", NULL },
+	{ "application/x-nsv-vp3-mp3", "nsv", "video/x-nsv" },
+	{ "video/flv", "flv", "application/x-flash-video" },
 };
 
 totemScriptablePlugin::totemScriptablePlugin (totemPlugin *aPlugin)
