@@ -24,7 +24,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <string.h>
 
 #include "totem-menu.h"
@@ -495,7 +494,7 @@ on_recent_file_item_activated (GtkAction *action,
 	totem_signal_block_by_data (totem->playlist, totem);
 
 	end = totem_playlist_get_last (totem->playlist);
-	playlist_changed = totem_playlist_add_mrl (totem->playlist, uri, NULL);
+	playlist_changed = totem_playlist_add_mrl_with_cursor (totem->playlist, uri, NULL);
 	gtk_recent_manager_add_item (totem->recent_manager, uri);
 
 	totem_signal_unblock_by_data (totem->playlist, totem);
@@ -612,9 +611,7 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
 void
 totem_setup_recent (Totem *totem)
 {
-	GdkScreen *screen;
-	screen = gtk_widget_get_screen (totem->win);
-	totem->recent_manager = gtk_recent_manager_get_for_screen (screen);
+	totem->recent_manager = gtk_recent_manager_get_default ();
 	totem->recent_action_group = NULL;
 	totem->recent_ui_id = 0;
 
@@ -631,6 +628,8 @@ totem_action_add_recent (Totem *totem, const char *filename)
 	GtkRecentData data;
 	char *groups[] = { NULL, NULL };
 
+	memset (&data, 0, sizeof (data));
+
 	data.mime_type = gnome_vfs_get_mime_type (filename);
 	if (data.mime_type == NULL) {
 		/* No mime-type means warnings, and it breaks when adding
@@ -658,12 +657,11 @@ totem_action_add_recent (Totem *totem, const char *filename)
 		groups[0] = "Totem";
 	}
 
-	data.description = NULL;
 	data.app_name = g_strdup (g_get_application_name ());
 	data.app_exec = g_strjoin (" ", g_get_prgname (), "%u", NULL);
 	data.groups = groups;
 	gtk_recent_manager_add_full (totem->recent_manager,
-			filename, &data);
+				     filename, &data);
 
 	g_free (data.display_name);
 	g_free (data.mime_type);
@@ -839,6 +837,8 @@ on_movie_menu_select (GtkMenuItem *movie_menuitem, Totem *totem)
 
 	g_list_foreach (devices, (GFunc) g_object_unref, NULL);
 	g_list_free (devices);
+
+	totem->drives_changed = FALSE;
 }
 
 static void
@@ -1015,13 +1015,13 @@ previous_chapter_action_callback (GtkAction *action, Totem *totem)
 static void
 skip_forward_action_callback (GtkAction *action, Totem *totem)
 {
-	totem_action_seek_relative (totem, SEEK_FORWARD_OFFSET);
+	totem_action_seek_relative (totem, SEEK_FORWARD_OFFSET * 1000);
 }
 
 static void
 skip_backwards_action_callback (GtkAction *action, Totem *totem)
 {
-	totem_action_seek_relative (totem, SEEK_BACKWARD_OFFSET);
+	totem_action_seek_relative (totem, SEEK_BACKWARD_OFFSET * 1000);
 }
 
 static void
@@ -1087,6 +1087,8 @@ about_action_callback (GtkAction *action, Totem *totem)
 				     "logo-icon-name", "totem",
 				     "license", license,
 				     "wrap-license", TRUE,
+				     "website-label", _("Totem Website"),
+				     "website", "http://www.gnome.org/projects/totem/",
 				     NULL);
 
 	g_free (backend_version);
@@ -1180,6 +1182,8 @@ show_controls_action_callback (GtkToggleAction *action, Totem *totem)
 
 	show = gtk_toggle_action_get_active (action);
 
+	g_message ("show_controls_action_callback %d", show);
+
 	/* Let's update our controls visibility */
 	if (show)
 		totem->controls_visibility = TOTEM_CONTROLS_VISIBLE;
@@ -1276,7 +1280,7 @@ static const GtkToggleActionEntry toggle_entries[] = {
 	{ "shuffle-mode", NULL, N_("Shuff_le Mode"), NULL, N_("Set the shuffle mode"), G_CALLBACK (shuffle_mode_action_callback), FALSE },
 	{ "deinterlace", NULL, N_("_Deinterlace"), "I", N_("Deinterlace"), G_CALLBACK (deinterlace_action_callback), FALSE },
 	{ "show-controls", NULL, N_("Show _Controls"), "H", N_("Show controls"), G_CALLBACK (show_controls_action_callback), TRUE },
-	{ "sidebar", NULL, N_("_Sidebar"), "F9", N_("Show or hide the sidebar"), G_CALLBACK (show_sidebar_action_callback), TRUE }
+	{ "sidebar", NULL, N_("S_idebar"), "F9", N_("Show or hide the sidebar"), G_CALLBACK (show_sidebar_action_callback), TRUE }
 };
 
 static const GtkRadioActionEntry aspect_ratio_entries[] = {
@@ -1310,6 +1314,7 @@ totem_ui_manager_connect_proxy_callback (GtkUIManager *ui_manager,
 			image = gtk_image_new_from_pixbuf (icon);
 			gtk_image_menu_item_set_image
 				(GTK_IMAGE_MENU_ITEM (widget), image);
+			g_object_unref (G_OBJECT (icon));
 		}
 	}
 }
@@ -1319,7 +1324,7 @@ totem_ui_manager_setup (Totem *totem)
 {
 	char *filename;
 	GtkWidget *menubar;
-	GtkWidget *menubar_box;
+	GtkBox *menubar_box;
 	GtkAction *action;
 
 	totem->main_action_group = gtk_action_group_new ("main-action-group");
@@ -1401,7 +1406,7 @@ totem_ui_manager_setup (Totem *totem)
 	g_free (filename);
 
 	menubar = gtk_ui_manager_get_widget (totem->ui_manager, "/tmw-menubar");
-	menubar_box = glade_xml_get_widget (totem->xml, "tmw_menubar_box");
-	gtk_box_pack_start (GTK_BOX (menubar_box), menubar, FALSE, FALSE, 0);
+	menubar_box = GTK_BOX (gtk_builder_get_object (totem->xml, "tmw_menubar_box"));
+	gtk_box_pack_start (menubar_box, menubar, FALSE, FALSE, 0);
 }
 
